<?php

namespace Drupal\openapi_decoupled_toolbox;

/**
 * Common functions for inspecting decoupled toolbox resources.
 */
trait OpenapiDecoupledToolboxTrait {

  /**
   * Gets entity types that are enabled for decoupled toolbox.
   *
   * @param string $entity_type_id
   *   The entity type id.
   *
   * @return \Drupal\openapi_decoupled_toolbox\Entity\OpenApiDecoupledToolbox[]
   *   Entity types that are enabled.
   */
  protected function getDecoupledToolboxEnabledEntityTypes($entity_type_id = NULL) {
    if (!empty($entity_type_id)) {
      return [
        $this->entityTypeManager->getStorage('open_api_decoupled_toolbox')
          ->loadByProperties(['entity_type' => $entity_type_id]),
      ];
    }
    return $this->entityTypeManager->getStorage('open_api_decoupled_toolbox')
      ->loadMultiple();
  }

  /**
   * @return array
   */
  protected function getQueryParameter() {
    $parameters = [];
    $parameters[] = [
      'name' => 'display',
      //   'type' => 'string',
      'schema' => ['type' => 'string'],
      'in' => 'query',
    ];
    $parameters[] = [
      'name' => 'offset',
      //'type' => 'integer',
      'schema' => ['type' => 'integer'],
      'in' => 'query',
      'required' => TRUE,
    ];
    $parameters[] = [
      'name' => 'limit',
      'schema' => ['type' => 'integer'],
      'in' => 'query',
      'required' => TRUE,
    ];
    return $parameters;
  }

}
